@@ -226,13 +226,13 @@
 			# Echoe the command line to the console
 			#
 			pr1 <- substr(options("prompt")$prompt, 1,2)
-			cat(deparse(cmd, width = 500), "\n", pr1, sep="")
+			cat(deparse(cmd, width.cutoff = 500), "\n", pr1, sep="")
 		}
 		#
 		# Execute the command
 		#
 		eval.parent(cmd)
-		if (history) rewriteHistory(deparse(cmd, width = 500))
+		if (history) rewriteHistory(deparse(cmd, width.cutoff = 500))
 	}
 #
 # Place the three buttons
